@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 
 
 class LsfQueue(SimQueue, ProtocolInterface):
-    """ Queue system for LSF
+    """Queue system for LSF
 
     Parameters
     ----------
@@ -274,14 +274,10 @@ class LsfQueue(SimQueue, ProtocolInterface):
 
             # Move completed trajectories
             if self.datadir is not None:
-                datadir = os.path.abspath(self.datadir)
-                if not os.path.isdir(datadir):
-                    os.mkdir(datadir)
                 simname = os.path.basename(os.path.normpath(workdir))
-                # create directory for new file
-                odir = os.path.join(datadir, simname)
-                os.mkdir(odir)
-                f.write("\nmv *.{} {}".format(self.trajext, odir))
+                datadir = os.path.abspath(os.path.join(self.datadir, simname))
+                os.makedirs(datadir, exist_ok=True)
+                f.write(f"\nmv *.{self.trajext} {datadir}")
 
         os.chmod(fname, 0o700)
 
@@ -297,7 +293,7 @@ class LsfQueue(SimQueue, ProtocolInterface):
         )
 
     def submit(self, dirs):
-        """ Submits all directories
+        """Submits all directories
 
         Parameters
         ----------
@@ -331,7 +327,7 @@ class LsfQueue(SimQueue, ProtocolInterface):
                 raise
 
     def inprogress(self):
-        """ Returns the sum of the number of running and queued workunits of the specific group in the engine.
+        """Returns the sum of the number of running and queued workunits of the specific group in the engine.
 
         Returns
         -------
@@ -375,8 +371,7 @@ class LsfQueue(SimQueue, ProtocolInterface):
         return l_total
 
     def stop(self):
-        """ Cancels all currently running and queued jobs
-        """
+        """Cancels all currently running and queued jobs"""
         import getpass
 
         if self.jobname is None:
